# pytuyapi-ipc

This repository was created due to current implementations of tuya protocol via python seem to be out of date. Created as part of my research with roborock, 
and it seems to be the only library that can communicate correctly.

It uses tuyapi-ipc to communicate with tuyapi over file descriptors

```bash
pip install pytuyapi-ipc
```
